@@ -16,13 +16,9 @@ from bigquery_frame.data_diff.package import (
     STRUCT_SEPARATOR_ALPHA,
     canonize_col,
 )
-from bigquery_frame.data_type_utils import get_common_columns
+from bigquery_frame.data_type_utils import flatten_schema, get_common_columns
 from bigquery_frame.dataframe import cols_to_str, is_nullable, is_repeated
-from bigquery_frame.transformations import (
-    flatten_schema,
-    harmonize_dataframes,
-    normalize_arrays,
-)
+from bigquery_frame.transformations import harmonize_dataframes, normalize_arrays
 from bigquery_frame.utils import quote, quote_columns, strip_margin
 
 
@@ -106,9 +102,9 @@ class DataframeComparator:
         c1 STRING (nullable)
         c2 INTEGER (nullable)
         >>> schema = [
-        ...     SchemaField('id', 'INTEGER', 'NULLABLE', 'An id', (), None),
-        ...     SchemaField('c1', 'STRING', 'REQUIRED', 'A string column', (), None),
-        ...     SchemaField('c2', 'INTEGER', 'NULLABLE', 'An int column', (), None)
+        ...     SchemaField(name='id', field_type='INTEGER', mode='NULLABLE', description='An id'),
+        ...     SchemaField(name='c1', field_type='STRING', mode='REQUIRED', description='A string column'),
+        ...     SchemaField(name='c2', field_type='INTEGER', mode='NULLABLE', description='An int column')
         ... ]
         >>> print('\\n'.join(df_comparator._schema_to_string(schema, include_nullable=True, include_metadata=True)))
         id INTEGER (nullable) An id
