@@ -19,7 +19,6 @@ from bigquery_frame.column import Column, StringOrColumn, cols_to_str
 from bigquery_frame.conf import ELEMENT_COL_NAME, REPETITION_MARKER, STRUCT_SEPARATOR
 from bigquery_frame.nested import resolve_nested_columns
 from bigquery_frame.printing import print_results
-from bigquery_frame.transformations_impl.flatten_schema import flatten_schema
 from bigquery_frame.utils import assert_true, indent, quote, str_to_cols, strip_margin
 
 if TYPE_CHECKING:
@@ -54,15 +53,15 @@ SUPPORTED_JOIN_TYPES = {
 }
 
 
-def is_repeated(schema_field: SchemaField):
+def is_repeated(schema_field: SchemaField) -> bool:
     return schema_field.mode == "REPEATED"
 
 
-def is_struct(schema_field: SchemaField):
+def is_struct(schema_field: SchemaField) -> bool:
     return schema_field.field_type == "RECORD"
 
 
-def is_nullable(schema_field: SchemaField):
+def is_nullable(schema_field: SchemaField) -> bool:
     return schema_field.mode == "NULLABLE"
 
 
@@ -77,7 +76,7 @@ def schema_to_simple_string(schema: List[SchemaField]):
     >>> bq = BigQueryBuilder()
     >>> df = bq.sql('SELECT 1 as id, STRUCT(1 as a, [STRUCT(2 as c, 3 as d)] as b, [4, 5] as e) as s')
     >>> print(df.schema)  # noqa: E501
-    [SchemaField('id', 'INTEGER', 'NULLABLE', None, (), None), SchemaField('s', 'RECORD', 'NULLABLE', None, (SchemaField('a', 'INTEGER', 'NULLABLE', None, (), None), SchemaField('b', 'RECORD', 'REPEATED', None, (SchemaField('c', 'INTEGER', 'NULLABLE', None, (), None), SchemaField('d', 'INTEGER', 'NULLABLE', None, (), None)), None), SchemaField('e', 'INTEGER', 'REPEATED', None, (), None)), None)]
+    [SchemaField('id', 'INTEGER', 'NULLABLE', None, None, (), None), SchemaField('s', 'RECORD', 'NULLABLE', None, None, (SchemaField('a', 'INTEGER', 'NULLABLE', None, None, (), None), SchemaField('b', 'RECORD', 'REPEATED', None, None, (SchemaField('c', 'INTEGER', 'NULLABLE', None, None, (), None), SchemaField('d', 'INTEGER', 'NULLABLE', None, None, (), None)), None), SchemaField('e', 'INTEGER', 'REPEATED', None, None, (), None)), None)]
     >>> schema_to_simple_string(df.schema)
     'id:INTEGER,s:STRUCT<a:INTEGER,b:ARRAY<STRUCT<c:INTEGER,d:INTEGER>>,e:ARRAY<INTEGER>>'
 
@@ -285,7 +284,7 @@ class DataFrame:
         """Creates or replace a persisted temporary table.
 
         >>> from bigquery_frame.bigquery_builder import BigQueryBuilder
-            >>> bq = BigQueryBuilder()
+        >>> bq = BigQueryBuilder()
         >>> df = bq.sql("SELECT 1 as id")
         >>> df.createOrReplaceTempTable("temp_table")
         >>> bq.sql("SELECT * FROM temp_table").show()
@@ -303,7 +302,7 @@ class DataFrame:
         """Creates or replaces a local temporary view with this :class:`DataFrame`.
 
         >>> from bigquery_frame.bigquery_builder import BigQueryBuilder
-            >>> bq = BigQueryBuilder()
+        >>> bq = BigQueryBuilder()
         >>> df = bq.sql("SELECT 1 as id")
         >>> df.createOrReplaceTempView("temp_view")
         >>> bq.sql("SELECT * FROM temp_view").show()
@@ -984,7 +983,7 @@ class DataFrame:
         Unlike the :func:`withColumn` method, this method works on repeated elements
         and records (arrays and arrays of struct).
 
-        The syntax for column names works as follow:
+        The syntax for column names works as follows:
         - "." is the separator for struct elements
         - "!" must be appended at the end of fields that are repeated
         - Corresponding column expressions must use the complete field names for non-repeated structs
@@ -1057,6 +1056,8 @@ class DataFrame:
         :param columns: a Dict[column_alias, column_expression] of columns to select
         :return:
         """
+        from bigquery_frame.data_type_utils import flatten_schema
+
         schema_flat = flatten_schema(
             self.schema, explode=True, struct_separator=STRUCT_SEPARATOR, repetition_marker=REPETITION_MARKER
         )
